@@ -1,4 +1,4 @@
-from mtpiclick import point
+from mtpiclick.point import point
 
 bottom = 725
 left = 108
@@ -17,4 +17,4 @@ key_3 = point(244, 347)
 key_ok = point(927, 466)
 login_ok = point(389, 424)
 capture = point(807,864)
-hmi = point(760, 0)
\ No newline at end of file
+frame = point(760, 0)
\ No newline at end of file
